pub struct TransactionError {
pub transaction_error: i32,
pub instruction_error: Option<InstructionError>,
pub transaction_details: Option<TransactionDetails>,
}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Fields
transaction_error: i32๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.instruction_error: Option<InstructionError>๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.transaction_details: Option<TransactionDetails>๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Implementations
Sourceimpl TransactionError
impl TransactionError
Sourcepub fn transaction_error(&self) -> TransactionErrorType
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn transaction_error(&self) -> TransactionErrorType
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Returns the enum value of transaction_error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_transaction_error(&mut self, value: TransactionErrorType)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn set_transaction_error(&mut self, value: TransactionErrorType)
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Sets transaction_error to the provided enum value.